Test Pattern Matching
open | ../tests/html/test_verifications.html |
verifyValue | theText | *text*
verifyValue | theHidden | * hidden value
verifyText | theSpan | * span
verifySelected | theSelect | second *
verifySelectOptions | theSelect | first*,second*,third*
verifyAttribute | theText@class | ?oo
verifyValue | theTextarea | Line 1*
verifyValue | theText | regexp:^[a-z ]+$
verifyValue | theHidden | regexp:dd
verifyText | theSpan | regexp:span$
verifySelected | theSelect | regexp:second .*
verifyAttribute | theText@class | regexp:^f
verifyValue | theText | regex:^[a-z ]+$
verifyValue | theHidden | regex:dd
verifyText | theSpan | regex:span$
verifySelected | theSelect | regex:second .*
verifyAttribute | theText@class | regex:^f
verifyValue | theText | exact:the text value
verifySelected | theSelect | exact:second option
verifySelectOptions | theSelect | regexp:^first.*?,second option,third*